@@ -444,5 +444,67 @@ expint.E1 <- function(x) {
 
 
 
+ghn100 <-
+c(-13.4064873381449, -12.8237997494878, -12.3429642228597, -11.9150619431142, 
+-11.521415400787, -11.1524043855851, -10.8022607536847, -10.4671854213428, 
+-10.1445099412928, -9.83226980777795, -9.5289658233901, -9.23342089021916, 
+-8.94468921732547, -8.66199616813451, -8.38469694041627, -8.11224731116279, 
+-7.84418238446082, -7.58010080785749, -7.31965282230454, -7.06253106024886, 
+-6.80846335285879, -6.55720703192154, -6.30854436111214, -6.0622788326143, 
+-5.81823213520352, -5.57624164932992, -5.33615836013836, -5.09784510508914, 
+-4.86117509179121, -4.62603063578716, -4.39230207868269, -4.15988685513103, 
+-3.92868868342767, -3.69861685931849, -3.46958563641859, -3.24151367963101, 
+-3.01432358033115, -2.78794142398199, -2.56229640237261, -2.33732046390688, 
+-2.11294799637119, -1.88911553742701, -1.66576150874151, -1.44282597021593, 
+-1.22025039121895, -0.997977436098106, -0.775950761540146, -0.554114823591618, 
+-0.332414692342232, -0.11079587242244, 0.110795872422439, 0.332414692342232, 
+0.554114823591617, 0.775950761540145, 0.997977436098105, 1.22025039121895, 
+1.44282597021593, 1.66576150874151, 1.88911553742701, 2.11294799637119, 
+2.33732046390688, 2.5622964023726, 2.78794142398199, 3.01432358033115, 
+3.24151367963101, 3.46958563641859, 3.69861685931849, 3.92868868342767, 
+4.15988685513103, 4.39230207868269, 4.62603063578716, 4.86117509179121, 
+5.09784510508914, 5.33615836013836, 5.57624164932993, 5.81823213520351, 
+6.0622788326143, 6.30854436111214, 6.55720703192153, 6.80846335285879, 
+7.06253106024886, 7.31965282230453, 7.58010080785749, 7.84418238446082, 
+8.11224731116279, 8.38469694041626, 8.66199616813451, 8.94468921732548, 
+9.23342089021915, 9.52896582339012, 9.83226980777795, 10.1445099412928, 
+10.4671854213428, 10.8022607536847, 11.1524043855851, 11.521415400787, 
+11.9150619431142, 12.3429642228597, 12.8237997494878, 13.4064873381449
+)
+ghw100 <-
+c(5.90806786503149e-79, 1.97286057487953e-72, 3.08302899000321e-67, 
+9.01922230369242e-63, 8.51888308176111e-59, 3.45947793647603e-55, 
+7.19152946346349e-52, 8.59756395482676e-49, 6.42072520534849e-46, 
+3.18521787783596e-43, 1.10047068271428e-40, 2.74878488435709e-38, 
+5.11623260438594e-36, 7.27457259688812e-34, 8.06743427870884e-32, 
+7.10181222638517e-30, 5.03779116621273e-28, 2.91735007262926e-26, 
+1.39484152606877e-24, 5.56102696165936e-23, 1.86499767513029e-21, 
+5.30231618313167e-20, 1.28683292112113e-18, 2.68249216476057e-17, 
+4.82983532170314e-16, 7.5488968779154e-15, 1.02887493735098e-13, 
+1.22787851441009e-12, 1.28790382573158e-11, 1.19130063492903e-10, 
+9.74792125387112e-10, 7.07585728388942e-09, 4.568127508485e-08, 
+2.62909748375372e-07, 1.35179715911036e-06, 6.22152481777778e-06, 
+2.56761593845487e-05, 9.51716277855096e-05, 0.000317291971043304, 
+0.000952692188548621, 0.00257927326005907, 0.00630300028560806, 
+0.0139156652202317, 0.0277791273859335, 0.0501758126774289, 0.0820518273912242, 
+0.121537986844105, 0.163130030502782, 0.198462850254188, 0.218892629587438, 
+0.21889262958744, 0.198462850254186, 0.163130030502783, 0.121537986844104, 
+0.082051827391225, 0.0501758126774289, 0.0277791273859336, 0.0139156652202318, 
+0.00630300028560809, 0.00257927326005912, 0.000952692188548612, 
+0.000317291971043303, 9.51716277855086e-05, 2.5676159384549e-05, 
+6.22152481777782e-06, 1.35179715911039e-06, 2.62909748375376e-07, 
+4.56812750848495e-08, 7.07585728388942e-09, 9.74792125387167e-10, 
+1.19130063492907e-10, 1.28790382573154e-11, 1.22787851441012e-12, 
+1.02887493735101e-13, 7.5488968779154e-15, 4.82983532170362e-16, 
+2.68249216476036e-17, 1.28683292112121e-18, 5.30231618313197e-20, 
+1.86499767513026e-21, 5.56102696165912e-23, 1.39484152606877e-24, 
+2.91735007262916e-26, 5.03779116621305e-28, 7.10181222638506e-30, 
+8.06743427870919e-32, 7.2745725968875e-34, 5.1162326043855e-36, 
+2.74878488435732e-38, 1.10047068271418e-40, 3.18521787783605e-43, 
+6.42072520534922e-46, 8.59756395482676e-49, 7.1915294634638e-52, 
+3.45947793647628e-55, 8.51888308176039e-59, 9.01922230369063e-63, 
+3.08302899000303e-67, 1.97286057487992e-72, 5.90806786503182e-79
+)
+
 
 
